@@ -4,12 +4,12 @@
 =end meta
 =cut
 
-Contentment::Security->check_permission('Contentment::Node::Blog::view_blog');
+$context->security->check_permission('Contentment::Node::Blog::view_blog');
 
-if (Contentment::Security->has_permission(
+if ($context->security->has_permission(
 'Contentment::Node::Blog::edit_blog')) {
     print qq(<p><a href="blog/edit.html">Create Blog</a></p>);
 }
 
 my @blogs = Contentment::Node::Blog->search;
-Contentment::Theme->theme('blogs', { blogs => \@blogs });
+$context->theme('blogs', { blogs => \@blogs });
