@@ -4,7 +4,7 @@
 =end meta
 =cut
 
-Contentment::Security->check_permission('Contentment::Node::Blog::view_blog');
+$context->security->check_permission('Contentment::Node::Blog::view_blog');
 
 my $self = shift;
 my %args = @_;
@@ -12,4 +12,4 @@ my %args = @_;
 my $blog = Contentment::Node::Blog->retrieve($args{id});
 $self->properties->{title}       = $blog->title;
 $self->properties->{description} = $blog->description;
-Contentment::Theme->theme('blog', { blog => $blog });
+$context->theme('blog', { blog => $blog });
