@@ -3,10 +3,10 @@ package Contentment::Template::Plugin::Security;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.11';
 
 use base qw/ Contentment::Security Template::Plugin /;
 
-sub new { Contentment::Security->instance; }
+sub new { Contentment->context->security; }
 
 1
