@@ -6,9 +6,9 @@ use warnings;
 use Contentment::Setting;
 use base qw/ Template::Plugin /;
 
-our $VERSION = '0.04';
+our $VERSION = '0.11';
 
 sub new { bless {}, $_[0]; }
-sub settings { Contentment::Setting->instance; }
+sub settings { Contentment->settings; }
 
 1
