@@ -3,10 +3,10 @@ package Contentment::Template::Plugin::Site;
 use strict;
 use warnings;
 
-our $VERSION = 0.09;
+our $VERSION = '0.11';
 
 use base qw/ Template::Plugin /;
 
-sub new { return Contentment::Site->current_site; }
+sub new { return Contentment->context->current_site; }
 
 1
