@@ -8,7 +8,8 @@ our $VERSION = '0.02';
 sub indexes { return (Contentment::Test::Index->instance) }
 
 sub register_indexer {
-    Contentment::Index->register_index(bless {}, 'Contentment::Test::Indexer');
+    my $context = shift;
+    $context->catalog->register_indexer(bless {}, 'Contentment::Test::Indexer');
 }
 
 1
